import { select } from 'd3';
import { map } from './map';

const covidDataUrl =
  'https://raw.githubusercontent.com/lakshmi-keerthi/lakshmi-keerthi.github.io/main/covid_data_cleaned.csv';

export const main = (container, { state, setState }) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const { data } = state;

  if (data && data !== 'LOADING') {
    svg.call(map, {
      data,
    });
  }

  if (data === undefined) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));
    fetch(covidDataUrl)
      .then((response) => response.text())
      .then((csvData) => {
        // Convert CSV data to JSON
        const data = d3.csvParse(csvData);
        setState((state) => ({
          ...state,
          data,
        }));
      });
  }
};
