import { geoNaturalEarth1, geoPath } from 'd3';

const projection = geoNaturalEarth1();
const path = geoPath(projection);

export const map = (selection, { data }) => {
  selection
    .selectAll('path.country')
    .data(data.features)
    .join('path')
    .attr('d', path)
    .attr('class', 'country')
    .attr('stroke', 'white')
    .attr('stroke-width', 0.5)
    .attr('fill', (d) => {
      // Get the country name
      const country = d.properties.name;
      // Filter the COVID-19 data for the current country
      const countryData = data.filter(
        (item) => item.location === country,
      );
      // Calculate the total number of cases for the country
      const totalCases = countryData.reduce(
        (acc, cur) => acc + parseInt(cur.total_cases),
        0,
      );
      // Return a color based on the total number of cases
      return colorScale(totalCases);
    });
};

const colorScale = d3
  .scaleSequential(d3.interpolateReds)
  .domain([0, 1000000]); // Adjust domain as needed
